@@ -1,4 +1,6 @@
 import os
+import sys
+
 
 def cal_peaq(ref, est):
     '''
@@ -6,7 +8,7 @@ def cal_peaq(ref, est):
     :param est:
     :return:
     '''
-    cmd = 'peaqb.exe -r '+ ref + ' -t ' + est
+    cmd = sys.prefix + '/peaqb.exe -r '+ ref + ' -t ' + est
     result = os.popen(cmd)
     res = result.read()
     for line in res.splitlines():
