@@ -1,7 +1,7 @@
 # -*- coding: UTF-8 -*-
-import sys
-sys.path.append('./')
-sys.path.append('../')
+import sys,os
+from os import  path
+sys.path.append(os.path.dirname(path.dirname(__file__)))
 import ctypes
 from ctypes import *
 from commFunction import emxArray_real_T,get_data_of_ctypes_
