@@ -20,18 +20,25 @@ class emxArray_real_T(Structure):
           ("canFreeData", c_uint),
 ]
 
+def convert_error_header(wavfile,channels=1, bits=16, sample_rate=16000):
+    suffix = os.path.splitext(wavfile)[-1]
+    assert suffix == '.wav'
 
-def get_max_cc_by_dll(refData, testData,mydll,step):
-    """
-    (double *x, double *y,long xLenth,long yLenth,long step,double *maxcc,long *startPoint)
-    """
-
-    refstruct = np.ascontiguousarray(refData, dtype=c_double).ctypes.data_as(POINTER(c_double))
-    teststruct = np.ascontiguousarray(testData, dtype=c_double).ctypes.data_as(POINTER(c_double))
-    mydll.get_max_pcc.argtypes = [POINTER(c_double),POINTER(c_double),c_long,c_long,c_long,POINTER(c_double),POINTER(c_long)]
-    max_cc,start_point = c_double(0.0),c_long(0)
-    mydll.get_max_pcc(refstruct,teststruct,c_long(len(refData)),c_long(len(testData)),c_long(step),byref(max_cc),byref(start_point))
-    return max_cc.value,start_point.value
+    newFileName = wavfile[:-4] + '_convertHeader.wav'
+    pcmf = open(wavfile, 'rb')
+    pcmdata = pcmf.read()
+    pcmf.close()
+    if bits % 8 != 0:
+        raise ValueError("bits % 8 must == 0. now bits:" + str(bits))
+    wavfile = wave.open(newFileName, 'wb')
+    wavfile.setnchannels(channels)
+    wavfile.setsampwidth(bits // 8)
+    wavfile.setframerate(sample_rate)
+    wavfile.writeframes(pcmdata)
+    wavfile.close()
+    time.sleep(1)
+    #os.remove(pcm_file)
+    return newFileName
 
 def get_data_array(filename):
     """
