@@ -35,10 +35,11 @@ from MOS_INFER.run_predict import cal_mos_infer
 from FUNCTION.audioFunction import isSlience,audioFormat,get_rms_level
 from Noise_Suppression.noiseFuction import  cal_noise_Supp
 from CLIPPING_DETECTION.audio_clip_detection import cal_clip_index
+from AEC_EVALUATION.FR_ECHO_DETECT import cal_fullref_echo
 allMetrics = ['G160','P563','POLQA','PESQ','STOI','STI','PEAQ','SDR',
               'SII','LOUDNESS','MUSIC','TRANSIENT','MATCH','GAINTABLE',
               'ATTACKRELEASE','MUSICSTA','AGCDELAY','SLIENCE','FORMAT',
-              'MATCHAEC','ERLE','AECMOS','AIMOS','TRMS','ARMS','NOISE','CLIP','DELAY']
+              'MATCHAEC','ERLE','AECMOS','AIMOS','TRMS','ARMS','NOISE','CLIP','DELAY','ECHO']
 
 
 class computeAudioQuality():
@@ -458,4 +459,16 @@ class computeAudioQuality():
         -------
 
         """
-        return cal_clip_index(pcm2wav(self.testFile, sample_rate=self.samplerate))
\ No newline at end of file
+        return cal_clip_index(pcm2wav(self.testFile, sample_rate=self.samplerate))
+
+
+    def ECHO(self):
+        """
+        Returns
+        -------
+
+        """
+        self.__double_end_check()
+        return cal_fullref_echo(pcm2wav(self.refFile, sample_rate=self.samplerate),
+                             pcm2wav(self.testFile, sample_rate=self.samplerate))
+
